from django.contrib.auth.mixins import LoginRequiredMixin
from django.contrib.auth.views import LoginView
from django.shortcuts import render, get_object_or_404, redirect
from django.urls import reverse_lazy
from django.views.generic import CreateView, ListView, DetailView

from .forms import RegistrationUserForm, OrderCreateForm
from .models import Product, Order


def index(request):
    products = Product.objects.order_by('-date')[:5]
    context = {'products': products}
    return render(request, 'index.html', context)


class RegistrationView(CreateView):
    form_class = RegistrationUserForm
    template_name = 'users/register.html'
    success_url = reverse_lazy('login')


class LoginView(LoginView):
    template_name = 'users/login.html'
    success_url = reverse_lazy('index')


class ProductListView(ListView):
    model = Product
    template_name = 'main/products.html'
    context_object_name = 'products'


class ProductDetailView(DetailView):
    model = Product
    template_name = 'main/product.html'
    context_object_name = 'product'


class ProfileView(ListView, LoginRequiredMixin):
    model = Order
    context_object_name = 'orders'
    template_name = 'users/profile.html'

    def get_queryset(self):
        return Order.objects.filter(customer=self.request.user)


def order_create(request, pk):
    product = get_object_or_404(Product, id=pk)
    Order.objects.create(customer=request.user, product=product)
    return redirect('profile')
